Module blaxel.core.sandbox.client.models.process_logs
=====================================================

Classes
-------

`ProcessLogs(logs: str, stderr: str, stdout: str)`
:   Attributes:
        logs (str):  Example: logs output.
        stderr (str):  Example: stderr output.
        stdout (str):  Example: stdout output.
    
    Method generated by attrs for class ProcessLogs.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `logs: str`
    :

    `stderr: str`
    :

    `stdout: str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :